@@ -358,8 +358,7 @@ class OvsHost(linux.LinuxDevice):
 
     def set_out_interface (self, bridge_name, out_if, *args):
         '''
-        Add some flows remote devices(*args): 从本主机上到达所有*args的包，全
-        部经由out_if
+        It's the same as add_vtep(), only different in the name.
         '''
         if self["fail-mode"] != "secure":
             #Don't need configure out_if explicitly in standalone mode.
